sequencetools.negate_sequence_elements_cyclically
=================================================

.. autofunction:: abjad.tools.sequencetools.negate_sequence_elements_cyclically.negate_sequence_elements_cyclically
